@@ -8,7 +8,7 @@ from typing import Optional, List, Callable, TypeVar
 from abc import ABC, abstractmethod
 from functools import lru_cache
 
-from .structure import *
+from .version import version
 
 TZ = datetime.timezone(offset=datetime.timedelta(seconds=time.timezone))
 
@@ -203,13 +203,6 @@ class Problem(Model):
     # Backlink
     assignment: "Assignment" = None
 
-    def weight(self) -> Decimal:
-        """Percentage weight of the problem in the assignment."""
-
-        if self.assignment.grading.weight() == 0:
-            return Decimal(0)
-        return self.grading.weight / self.assignment.grading.weight()
-
     @classmethod
     def load(cls, data: dict, assignment: "Assignment" = None) -> "Problem":
         """Load directly from a dictionary."""
